# Autogenerated by Astropy-affiliated package speclite's setup.py on 2020-11-24 01:56:15 UTC
import datetime

version = "0.11"
githash = "c426024551ca61c1a0af2ee733446b3e69b2a191"


major = 0
minor = 11
bugfix = 0

version_info = (major, minor, bugfix)

release = True
timestamp = datetime.datetime(2020, 11, 24, 1, 56, 15)
debug = False

astropy_helpers_version = "4.0.1"
